"""
Class object for BridgeAudio
Documentation: https://system-bridge.timmo.dev

Generated by generator/generator.py - 2021-02-20 16:48:42.854477
"""
from .base import BridgeBase


class Audio(BridgeBase):
    @property
    def id(self):
        return self.attributes.get("id", "")

    @property
    def name(self):
        return self.attributes.get("name", "")

    @property
    def manufacturer(self):
        return self.attributes.get("manufacturer", "")

    @property
    def revision(self):
        return self.attributes.get("revision", "")

    @property
    def driver(self):
        return self.attributes.get("driver", "")

    @property
    def default(self):
        return self.attributes.get("default", "")

    @property
    def channel(self):
        return self.attributes.get("channel", "")

    @property
    def type(self):
        return self.attributes.get("type", "")

    @property
    def p_in(self):
        return self.attributes.get("in", "")

    @property
    def out(self):
        return self.attributes.get("out", "")

    @property
    def status(self):
        return self.attributes.get("status", "")
